Post #
A Post is a message published on a Board. It also provides notifications to Projects affected by the Post.
Package : spaceone.api.board.v1
Post #
Post Methods:
create #
Creates a new Post under a specific Board. You must specify the board_id, title, and contents. The parameter category is not required but can be set in the scope of categories specified in the parent Board. You can make the new Post pinned or pop up by adjusting the parameters.
POST /board/v1/board/create
board_id (string)
Requiredtitle (string)
Requiredcontents (string)
Requiredcategory (string)
options (Struct)
writer (string)
files (string)
Repeateddomain_id (string)
{
"board_id": "board-123456789012",
"category": "developer",
"title": "title",
"contents": "This is contents.",
"options": {"is_popup": true},
"writer": "user1",
"domain_id": "domain-123456789012"
}board_id (string)
Requiredpost_id (string)
Requiredpost_type (PostType)
Requiredcategory (string)
Requiredtitle (string)
Requiredcontents (string)
Requiredoptions (Struct)
Requiredview_count (int32)
Requiredwriter (string)
Requiredscope (Scope)
Requiredfiles (ListValue)
Requireddomain_id (string)
Requireduser_id (string)
Requireduser_domain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Required
{
"board_id": "board-123456789012",
"post_id": "post-123456789012",
"post_type": "INTERNAL",
"category": "developer",
"title": "title",
"contents": "This is contents.",
"options": {
"is_pinned": false,
"is_popup": true
},
"view_count": 0,
"writer": "user1",
"scope": "DOMAIN",
"domain_id": "domain-123456789012",
"user_id": "user1@email.com",
"created_at": "2022-01-01T01:06:23.732Z",
"updated_at": "2022-01-01T01:06:23.732Z"
}update #
Updates a specific Post. You can make changes in Post settings, except board_id, post_id, and domain_id.
POST /board/v1/board/update
board_id (string)
Requiredpost_id (string)
Requiredcategory (string)
title (string)
contents (string)
options (Struct)
writer (string)
files (string)
Repeateddomain_id (string)
{
"board_id": "board-123456789012",
"post_id": "post-2118473ce15e",
"category": "developer",
"title": "title2",
"contents": "this is contents2.",
"options": {
"is_popup": false,
"is_pinned": true
},
"writer": "user1",
"domain_id": "domain-123456789012"
}board_id (string)
Requiredpost_id (string)
Requiredpost_type (PostType)
Requiredcategory (string)
Requiredtitle (string)
Requiredcontents (string)
Requiredoptions (Struct)
Requiredview_count (int32)
Requiredwriter (string)
Requiredscope (Scope)
Requiredfiles (ListValue)
Requireddomain_id (string)
Requireduser_id (string)
Requireduser_domain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Required
{
"board_id": "board-123456789012",
"post_id": "post-123456789012",
"post_type": "INTERNAL",
"category": "developer",
"title": "title",
"contents": "This is contents.",
"options": {
"is_pinned": false,
"is_popup": true
},
"view_count": 0,
"writer": "user1",
"scope": "DOMAIN",
"domain_id": "domain-123456789012",
"user_id": "user1@email.com",
"created_at": "2022-01-01T01:06:23.732Z",
"updated_at": "2022-01-01T01:06:23.732Z"
}send_notification #
Not Implemented
POST /board/v1/board/send-notification
delete #
Deletes a specific Post. You must specify the post_id of the Post to delete, and the board_id of the Board where the child Post to delete belongs.
POST /board/v1/board/delete
board_id (string)
Requiredpost_id (string)
Requireddomain_id (string)
{
"board_id": "board-b9aa34e65c60",
"post_id": "post-2118473ce15e",
"domain_id": "domain-123456789012"
}get #
Gets a specific Post. You must specify the post_id of the Post to get, and the board_id of the Board where the child Post to get belongs. Prints detailed information about the Post.
POST /board/v1/board/get
board_id (string)
Requiredpost_id (string)
Requiredonly (string)
Repeateddomain_id (string)
{
"board_id": "board-b9aa34e65c60",
"post_id": "post-2118473ce15e",
"domain_id": "domain-58010aa2e451"
}board_id (string)
Requiredpost_id (string)
Requiredpost_type (PostType)
Requiredcategory (string)
Requiredtitle (string)
Requiredcontents (string)
Requiredoptions (Struct)
Requiredview_count (int32)
Requiredwriter (string)
Requiredscope (Scope)
Requiredfiles (ListValue)
Requireddomain_id (string)
Requireduser_id (string)
Requireduser_domain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Required
{
"board_id": "board-123456789012",
"post_id": "post-123456789012",
"post_type": "INTERNAL",
"category": "developer",
"title": "title",
"contents": "This is contents.",
"options": {
"is_pinned": false,
"is_popup": true
},
"view_count": 0,
"writer": "user1",
"scope": "DOMAIN",
"domain_id": "domain-123456789012",
"user_id": "user1@email.com",
"created_at": "2022-01-01T01:06:23.732Z",
"updated_at": "2022-01-01T01:06:23.732Z"
}list #
Gets a list of all Posts. You can use a query to get a filtered list of Posts.
POST /board/v1/board/list
board_id (string)
Requiredpost_id (string)
post_type (PostType)
category (string)
writer (string)
scope (Scope)
user_id (string)
user_domain_id (string)
domain_id (string)
query (Query)
{
"board_id": "board-b9aa34e65c60",
"query": {}
}results (PostInfo)
RepeatedRequiredtotal_count (int32)
Required
{
"results": [
{
"board_id": "board-b9aa34e65c60",
"post_id": "post-2118473ce15e",
"post_type": "INTERNAL",
"category": "spaceone",
"title": "title2",
"contents": "this is contents2.",
"options": {
"is_popup": false,
"is_pinned": true
},
"view_count": 3,
"writer": "seolmin2",
"scope": "DOMAIN",
"domain_id": "domain-58010aa2e451",
"user_id": "user1@email.com",
"created_at": "2022-06-13T01:06:23.732Z",
"updated_at": "2022-06-13T01:06:23.732Z"
},
{
"board_id": "board-b9aa34e65c60",
"post_id": "post-532ae1191233",
"post_type": "INTERNAL",
"category": "flower",
"title": "작업공지",
"contents": "This is description",
"options": {
"is_pinned": true,
"is_popup": true
},
"writer": "권설민",
"scope": "PUBLIC",
"user_id": "supervisor",
"created_at": "2022-06-10T07:01:44.384Z",
"updated_at": "2022-06-10T07:01:44.384Z"
}
],
"total_count": 2
}stat #
POST /board/v1/board/stat
Message #
CreatePostRequest #
board_id (string)
Requiredtitle (string)
Requiredcontents (string)
Requiredcategory (string)
options (Struct)
writer (string)
files (string)
Repeateddomain_id (string)
GetPostRequest #
board_id (string)
Requiredpost_id (string)
Requiredonly (string)
Repeateddomain_id (string)
PostInfo #
board_id (string)
Requiredpost_id (string)
Requiredpost_type (PostType)
Requiredcategory (string)
Requiredtitle (string)
Requiredcontents (string)
Requiredoptions (Struct)
Requiredview_count (int32)
Requiredwriter (string)
Requiredscope (Scope)
Requiredfiles (ListValue)
Requireddomain_id (string)
Requireduser_id (string)
Requireduser_domain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Required
PostQuery #
board_id (string)
Requiredpost_id (string)
post_type (PostType)
category (string)
writer (string)
scope (Scope)
user_id (string)
user_domain_id (string)
domain_id (string)
query (Query)
PostRequest #
board_id (string)
Requiredpost_id (string)
Requireddomain_id (string)
PostStatQuery #
query (StatisticsQuery)
Requireddomain_id (string)
Required
PostsInfo #
results (PostInfo)
RepeatedRequiredtotal_count (int32)
Required
SendNotificationRequest #
board_id (string)
Requiredpost_id (string)
Requireddomain_id (string)
UpdatePostRequest #
board_id (string)
Requiredpost_id (string)
Requiredcategory (string)
title (string)
contents (string)
options (Struct)
writer (string)
files (string)
Repeateddomain_id (string)